pub struct CatalogGuard<'a> { /* private fields */ }Expand description
RAII guard for modifying a catalog with automatic publishing on drop.
Obtained via CatalogProducer::lock.
On drop, both the hang and MSF catalog tracks are updated if the catalog was mutated.
Methods from Deref<Target = Catalog>
pub const DEFAULT_NAME: &'static str = "catalog.json"
Sourcepub fn to_string_pretty(&self) -> Result<String, Error>
pub fn to_string_pretty(&self) -> Result<String, Error>
Serialize the catalog to a pretty string.